==> tentackle-swing-2.0.4-sources.jar: org/tentackle/swing/FormTableRowObject.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


package org.tentackle.swing;

import javax.swing.table.TableModel;


/**
 * An object representing a row in a {@link TableModel}.
 *
 * @author harald
 */
public interface FormTableRowObject {

 /**
   * Gets the value for a given column.<br>
   *
   * @param mColumn the datamodel-column
   * @return the column data object
   */
  public Object getValueAt (int mColumn);


  /**
   * Sets the value for a column.<br>
   *
   * @param mColumn the datamodel-column
   * @param value the cell value
   */
  public void setValueAt (int mColumn, Object value);


  /**
   * Gets the table.
   *
   * @return the table, null if model not known to a table
   */
  public FormTable getTable();

  
  /**
   * Gets the model.
   *
   * @return the data-model
   */
  public TableModel getModel();

  
  /**
   * Gets the model row.
   *
   * @return the data-model row
   */
  public int getRow();

}

==> tentackle-swing-8.3.0.0-sources.jar: org/tentackle/swing/FormTableRowObject.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


package org.tentackle.swing;

import javax.swing.table.TableModel;


/**
 * An object representing a row in a {@link TableModel}.
 *
 * @author harald
 */
public interface FormTableRowObject {

 /**
   * Gets the value for a given column.<br>
   *
   * @param mColumn the datamodel-column
   * @return the column data object
   */
  Object getValueAt (int mColumn);


  /**
   * Sets the value for a column.<br>
   *
   * @param mColumn the datamodel-column
   * @param value the cell value
   */
  void setValueAt (int mColumn, Object value);


  /**
   * Gets the table.
   *
   * @return the table, null if model not known to a table
   */
  FormTable getTable();

  
  /**
   * Gets the model.
   *
   * @return the data-model
   */
  TableModel getModel();

  
  /**
   * Gets the model row.
   *
   * @return the data-model row
   */
  int getRow();

}
